.. mdinclude:: ../README.md

Usage Examples
--------------

.. toctree::
   raw_reader_writer_example
   protobuf_example
   ros1_example
   ros2_example
   ros2_noenv_example

API Documentation
-----------------

.. toctree::
   :maxdepth: 2

   mcap-apidoc/index
   mcap-protobuf-apidoc/index
   mcap-ros1-apidoc/index
   mcap-ros2-apidoc/index

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
